PLAN_RESULT_SCHEMA = '''{
    "additionalProperties": false,
    "properties": {
        "tracedata": {
            "additionalProperties": false,
            "properties": {
                "client": {
                    "maxLength": 256,
                    "minLength": 2,
                    "pattern": "\\w+",
                    "type": "string"
                },
                "code": {
                    "maxLength": 256,
                    "minLength": 3,
                    "type": "string"
                },
                "method": {
                    "enum": [
                        "PLAN",
                        "CONVERT",
                        "ANALYTICS",
                        "PREDICT",
                        "ACTUALIZE",
                        "VALIDATE",
                        "ROUTE",
                        "MATRIX",
                        "CLUSTER"
                    ],
                    "type": "string"
                },
                "server": {
                    "maxLength": 256,
                    "minLength": 2,
                    "type": "string"
                },
                "service": {
                    "enum": [
                        "LASTMILE",
                        "DELIVERY",
                        "FIELDSERVICE",
                        "MERCHANDISER",
                        "ROUTING",
                        "CLUSTERING",
                        "ACCOUNT",
                        "STOCK",
                        "ADMIN"
                    ],
                    "type": "string"
                },
                "time": {
                    "format": "date-time",
                    "type": "string"
                }
            },
            "required": [
                "code"
            ],
            "type": "object"
        },
        "transfers": {
            "items": {
                "additionalProperties": false,
                "nullable": true,
                "properties": {
                    "input_amount": {
                        "default": 0,
                        "format": "double",
                        "maximum": 10000000,
                        "minimum": 0,
                        "type": "number"
                    },
                    "output_amount": {
                        "default": 0,
                        "format": "double",
                        "maximum": 10000000,
                        "minimum": 0,
                        "type": "number"
                    },
                    "storage_key": {
                        "maxLength": 1024,
                        "minLength": 1,
                        "type": "string"
                    },
                    "time_index": {
                        "default": 0,
                        "format": "int32",
                        "maximum": 60,
                        "minimum": 0,
                        "type": "integer"
                    }
                },
                "required": [
                    "storage_key",
                    "time_index",
                    "input_amount",
                    "output_amount"
                ],
                "type": "object"
            },
            "maxItems": 10000,
            "minItems": 0,
            "type": "array"
        },
        "validations": {
            "items": {
                "additionalProperties": false,
                "properties": {
                    "entity_key": {
                        "maxLength": 1024,
                        "type": "string"
                    },
                    "entity_type": {
                        "maxLength": 1024,
                        "type": "string"
                    },
                    "info": {
                        "type": "string"
                    },
                    "type": {
                        "enum": [
                            "info",
                            "warning",
                            "error"
                        ],
                        "nullable": false,
                        "type": "string"
                    }
                },
                "required": [
                    "type",
                    "info"
                ],
                "type": "object"
            },
            "maxItems": 10000,
            "minItems": 0,
            "type": "array"
        }
    },
    "required": [
        "transfers"
    ],
    "type": "object"
}'''


"""
    Veeroute.LSS Stock

    Veeroute.LSS Stock API  # noqa: E501

    The version of the OpenAPI document: 3.8.168672
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import vrt_lss_stock
from vrt_lss_stock.model.trace_data import TraceData


class TestTraceData(unittest.TestCase):
    """TraceData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTraceData(self):
        """Test TraceData"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TraceData()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

"""
    Veeroute.LSS Stock

    Veeroute.LSS Stock API  # noqa: E501

    The version of the OpenAPI document: 3.8.168672
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


__version__ = "3.8.168672"

# import ApiClient
from vrt_lss_stock.api_client import ApiClient

# import Configuration
from vrt_lss_stock.configuration import Configuration

# import exceptions
from vrt_lss_stock.exceptions import OpenApiException
from vrt_lss_stock.exceptions import ApiAttributeError
from vrt_lss_stock.exceptions import ApiTypeError
from vrt_lss_stock.exceptions import ApiValueError
from vrt_lss_stock.exceptions import ApiKeyError
from vrt_lss_stock.exceptions import ApiException



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from vrt_lss_stock.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from vrt_lss_stock.model.balance import Balance
from vrt_lss_stock.model.balance_delta import BalanceDelta
from vrt_lss_stock.model.balance_forecast import BalanceForecast
from vrt_lss_stock.model.check_result import CheckResult
from vrt_lss_stock.model.inline_response400 import InlineResponse400
from vrt_lss_stock.model.inline_response401 import InlineResponse401
from vrt_lss_stock.model.inline_response415 import InlineResponse415
from vrt_lss_stock.model.inline_response429 import InlineResponse429
from vrt_lss_stock.model.inline_response500 import InlineResponse500
from vrt_lss_stock.model.inline_response501 import InlineResponse501
from vrt_lss_stock.model.inline_response502 import InlineResponse502
from vrt_lss_stock.model.inline_response503 import InlineResponse503
from vrt_lss_stock.model.inline_response504 import InlineResponse504
from vrt_lss_stock.model.inline_response_default import InlineResponseDefault
from vrt_lss_stock.model.plan_result import PlanResult
from vrt_lss_stock.model.plan_task import PlanTask
from vrt_lss_stock.model.storage import Storage
from vrt_lss_stock.model.storage_tariff import StorageTariff
from vrt_lss_stock.model.trace_data import TraceData
from vrt_lss_stock.model.transfer import Transfer
from vrt_lss_stock.model.validate_result import ValidateResult
from vrt_lss_stock.model.validation import Validation
from vrt_lss_stock.model.version_result import VersionResult



from __future__ import absolute_import
from vrt_lss_stock.schemes.plan_task_schema import *
from vrt_lss_stock.schemes.plan_result_schema import *
from vrt_lss_stock.schemes.validate_task_schema import *
from vrt_lss_stock.schemes.validate_result_schema import *


"""
    Veeroute.LSS Stock

    Veeroute.LSS Stock API  # noqa: E501

    The version of the OpenAPI document: 3.8.168672
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import vrt_lss_stock
from vrt_lss_stock.api.plan_api import PlanApi  # noqa: E501


class TestPlanApi(unittest.TestCase):
    """PlanApi unit test stubs"""

    def setUp(self):
        self.api = PlanApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_plan(self):
        """Test case for plan

        Planning.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



PLAN_TASK_SCHEMA = '''{
    "additionalProperties": false,
    "properties": {
        "storages": {
            "items": {
                "additionalProperties": false,
                "nullable": true,
                "properties": {
                    "balance": {
                        "additionalProperties": false,
                        "nullable": true,
                        "properties": {
                            "max_limit": {
                                "default": 0,
                                "format": "double",
                                "maximum": 10000000,
                                "minimum": 0,
                                "type": "number"
                            },
                            "min_limit": {
                                "default": 0,
                                "format": "double",
                                "maximum": 10000000,
                                "minimum": 0,
                                "type": "number"
                            },
                            "start_amount": {
                                "default": 0,
                                "format": "double",
                                "maximum": 10000000,
                                "minimum": 0,
                                "type": "number"
                            }
                        },
                        "required": [
                            "start_amount",
                            "min_limit",
                            "max_limit"
                        ],
                        "type": "object"
                    },
                    "forecast": {
                        "items": {
                            "additionalProperties": false,
                            "nullable": true,
                            "properties": {
                                "delta": {
                                    "default": 0,
                                    "format": "double",
                                    "maximum": 10000000,
                                    "minimum": -10000000,
                                    "type": "number"
                                },
                                "time_index": {
                                    "default": 0,
                                    "format": "int32",
                                    "maximum": 1000,
                                    "minimum": 0,
                                    "type": "integer"
                                }
                            },
                            "required": [
                                "time_index",
                                "delta"
                            ],
                            "type": "object"
                        },
                        "maxLength": 1000,
                        "minLength": 0,
                        "type": "array"
                    },
                    "key": {
                        "maxLength": 1024,
                        "minLength": 1,
                        "type": "string"
                    },
                    "restricted_time_indexes": {
                        "items": {
                            "default": 0,
                            "format": "int32",
                            "maximum": 1000,
                            "minimum": 0,
                            "type": "integer"
                        },
                        "maxLength": 1000,
                        "minLength": 0,
                        "type": "array"
                    },
                    "tariff": {
                        "additionalProperties": false,
                        "nullable": true,
                        "properties": {
                            "storage_cost": {
                                "default": 0.001,
                                "format": "double",
                                "maximum": 10000,
                                "minimum": 0,
                                "type": "number"
                            },
                            "transfer_cost": {
                                "default": 0.001,
                                "format": "double",
                                "maximum": 1000000,
                                "minimum": 0,
                                "type": "number"
                            }
                        },
                        "required": [
                            "transfer_cost",
                            "storage_cost"
                        ],
                        "type": "object"
                    }
                },
                "required": [
                    "key",
                    "balance",
                    "forecast",
                    "tariff"
                ],
                "type": "object"
            },
            "maxItems": 10000,
            "minItems": 1,
            "type": "array"
        }
    },
    "required": [
        "storages"
    ],
    "type": "object"
}'''